==> automata-core-0.8.0-sources.jar: net/automatalib/ts/powerset/DeterministicPowersetView.java <==
/* Copyright (C) 2013-2019 TU Dortmund
 * This file is part of AutomataLib, http://www.automatalib.net/.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.automatalib.ts.powerset;

import java.util.Collection;
import java.util.Collections;

import net.automatalib.ts.DeterministicTransitionSystem;
import net.automatalib.ts.PowersetViewTS;

public class DeterministicPowersetView<S, I, T>
        implements DeterministicTransitionSystem<S, I, T>, PowersetViewTS<S, I, T, S, T> {

    private final DeterministicTransitionSystem<S, I, T> delegate;

    public DeterministicPowersetView(DeterministicTransitionSystem<S, I, T> delegate) {
        this.delegate = delegate;
    }

    @Override
    public T getTransition(S state, I input) {
        return delegate.getTransition(state, input);
    }

    @Override
    public S getSuccessor(T transition) {
        return delegate.getSuccessor(transition);
    }

    @Override
    public S getInitialState() {
        return delegate.getInitialState();
    }

    @Override
    public Collection<S> getOriginalStates(S state) {
        return Collections.singleton(state);
    }

    @Override
    public Collection<T> getOriginalTransitions(T transition) {
        return Collections.singleton(transition);
    }

}

==> automata-core-0.9.0-sources.jar: net/automatalib/ts/powerset/DeterministicPowersetView.java <==
/* Copyright (C) 2013-2020 TU Dortmund
 * This file is part of AutomataLib, http://www.automatalib.net/.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.automatalib.ts.powerset;

import java.util.Collection;
import java.util.Collections;

import net.automatalib.ts.DeterministicTransitionSystem;
import net.automatalib.ts.PowersetViewTS;
import org.checkerframework.checker.nullness.qual.Nullable;

public class DeterministicPowersetView<S, I, T>
        implements DeterministicTransitionSystem<S, I, T>, PowersetViewTS<S, I, T, S, T> {

    private final DeterministicTransitionSystem<S, I, T> delegate;

    public DeterministicPowersetView(DeterministicTransitionSystem<S, I, T> delegate) {
        this.delegate = delegate;
    }

    @Override
    public @Nullable T getTransition(S state, I input) {
        return delegate.getTransition(state, input);
    }

    @Override
    public S getSuccessor(T transition) {
        return delegate.getSuccessor(transition);
    }

    @Override
    public @Nullable S getInitialState() {
        return delegate.getInitialState();
    }

    @Override
    public Collection<S> getOriginalStates(S state) {
        return Collections.singleton(state);
    }

    @Override
    public Collection<T> getOriginalTransitions(T transition) {
        return Collections.singleton(transition);
    }

}
